@@ -36,6 +36,7 @@
 #define _XOPEN_SOURCE_EXTENDED
 #include "config.h"
 
+#include <assert.h>
 #include <stdio.h>
 #include <sys/select.h>
 #include <stdlib.h>
@@ -52,6 +53,8 @@
 #include <ncursesw/ncurses.h>
 #elif HAVE_NCURSES_H
 #include <ncurses.h>
+#elif HAVE_CURSES_H
+#include <curses.h>
 #endif
 
 #include "profanity.h"
@@ -72,8 +75,9 @@
 #include "xmpp/muc.h"
 #include "xmpp/roster_list.h"
 #include "xmpp/chat_state.h"
+#include "tools/editor.h"
 
-static WINDOW *inp_win;
+static WINDOW* inp_win;
 static int pad_start = 0;
 
 static struct timeval p_rl_timeout;
@@ -81,21 +85,22 @@ static struct timeval p_rl_timeout;
 static gint inp_timeout = 0;
 static gint no_input_count = 0;
 
-static FILE *discard;
+static FILE* discard;
 static fd_set fds;
 static int r;
-static char *inp_line = NULL;
+static char* inp_line = NULL;
 static gboolean get_password = FALSE;
 
 static void _inp_win_update_virtual(void);
 static int _inp_edited(const wint_t ch);
 static void _inp_win_handle_scroll(void);
-static int _inp_offset_to_col(char *str, int offset);
-static void _inp_write(char *line, int offset);
+static int _inp_offset_to_col(char* str, int offset);
+static void _inp_write(char* line, int offset);
+static void _inp_redisplay(void);
 
 static void _inp_rl_addfuncs(void);
-static int _inp_rl_getc(FILE *stream);
-static void _inp_rl_linehandler(char *line);
+static int _inp_rl_getc(FILE* stream);
+static void _inp_rl_linehandler(char* line);
 static int _inp_rl_tab_handler(int count, int key);
 static int _inp_rl_shift_tab_handler(int count, int key);
 static int _inp_rl_win_clear_handler(int count, int key);
@@ -123,16 +128,26 @@ static int _inp_rl_win_20_handler(int count, int key);
 static int _inp_rl_win_prev_handler(int count, int key);
 static int _inp_rl_win_next_handler(int count, int key);
 static int _inp_rl_win_next_unread_handler(int count, int key);
+static int _inp_rl_win_attention_handler(int count, int key);
+static int _inp_rl_win_attention_next_handler(int count, int key);
 static int _inp_rl_win_pageup_handler(int count, int key);
 static int _inp_rl_win_pagedown_handler(int count, int key);
 static int _inp_rl_subwin_pageup_handler(int count, int key);
 static int _inp_rl_subwin_pagedown_handler(int count, int key);
 static int _inp_rl_startup_hook(void);
 static int _inp_rl_down_arrow_handler(int count, int key);
+static int _inp_rl_scroll_handler(int count, int key);
+static int _inp_rl_send_to_editor(int count, int key);
+static int _inp_rl_print_newline_symbol(int count, int key);
 
 void
 create_input_window(void)
 {
+    /* MB_CUR_MAX is evaluated at runtime depending on the current
+     * locale, therefore we check that our own version is big enough
+     * and bail out if it isn't.
+     */
+    assert(MB_CUR_MAX <= PROF_MB_CUR_MAX);
 #ifdef NCURSES_REENTRANT
     set_escdelay(25);
 #else
@@ -143,22 +158,44 @@ create_input_window(void)
     rl_readline_name = "profanity";
     _inp_rl_addfuncs();
     rl_getc_function = _inp_rl_getc;
+    rl_redisplay_function = _inp_redisplay;
     rl_startup_hook = _inp_rl_startup_hook;
     rl_callback_handler_install(NULL, _inp_rl_linehandler);
 
     inp_win = newpad(1, INP_WIN_MAX);
-    wbkgd(inp_win, theme_attrs(THEME_INPUT_TEXT));;
+    wbkgd(inp_win, theme_attrs(THEME_INPUT_TEXT));
     keypad(inp_win, TRUE);
     wmove(inp_win, 0, 0);
 
     _inp_win_update_virtual();
 }
 
+static gboolean
+_inp_slashguard_check(void)
+{
+    if (get_password)
+        return false;
+    /* ignore empty and quoted messages */
+    if (inp_line == NULL || inp_line[0] == '\0' || inp_line[0] == '>')
+        return false;
+    if (!prefs_get_boolean(PREF_SLASH_GUARD))
+        return false;
+    size_t n = 1;
+    while (inp_line[n] != '\0' && n < 4) {
+        if (inp_line[n] == '/') {
+            cons_show("Your text contains a slash in the first 4 characters");
+            free(inp_line);
+            inp_line = NULL;
+            return true;
+        }
+        n++;
+    }
+    return false;
+}
+
 char*
 inp_readline(void)
 {
-    free(inp_line);
-    inp_line = NULL;
     p_rl_timeout.tv_sec = inp_timeout / 1000;
     p_rl_timeout.tv_usec = inp_timeout % 1000 * 1000;
     FD_ZERO(&fds);
@@ -169,7 +206,7 @@ inp_readline(void)
     pthread_mutex_lock(&lock);
     if (r < 0) {
         if (errno != EINTR) {
-            char *err_msg = strerror(errno);
+            const char* err_msg = strerror(errno);
             log_error("Readline failed: %s", err_msg);
         }
         return NULL;
@@ -178,34 +215,21 @@ inp_readline(void)
     if (FD_ISSET(fileno(rl_instream), &fds)) {
         rl_callback_read_char();
 
-        if (rl_line_buffer &&
-                rl_line_buffer[0] != '/' &&
-                rl_line_buffer[0] != '\0' &&
-                rl_line_buffer[0] != '\n') {
+        if (rl_line_buffer && rl_line_buffer[0] != '/' && rl_line_buffer[0] != '\0' && rl_line_buffer[0] != '\n') {
             chat_state_activity();
         }
 
         ui_reset_idle_time();
-        if (!get_password) {
-            _inp_write(rl_line_buffer, rl_point);
-        }
         inp_nonblocking(TRUE);
     } else {
         inp_nonblocking(FALSE);
         chat_state_idle();
     }
 
-    if (inp_line) {
-        if (!get_password && prefs_get_boolean(PREF_SLASH_GUARD)) {
-            if (strlen(inp_line) > 1) {
-                char *res = (char*) memchr (inp_line+1, '/', 3);
-                if (res) {
-                    cons_show("Your text contains a slash in the first 4 characters");
-                    return NULL;
-                }
-            }
-        }
-        return strdup(inp_line);
+    if (inp_line && !_inp_slashguard_check()) {
+        char* ret = inp_line;
+        inp_line = NULL;
+        return ret;
     } else {
         return NULL;
     }
@@ -225,15 +249,17 @@ inp_win_resize(void)
         }
     }
 
-    wbkgd(inp_win, theme_attrs(THEME_INPUT_TEXT));;
+    wbkgd(inp_win, theme_attrs(THEME_INPUT_TEXT));
+
     _inp_win_update_virtual();
 }
 
 void
 inp_nonblocking(gboolean reset)
 {
-    if (! prefs_get_boolean(PREF_INPBLOCK_DYNAMIC)) {
-        inp_timeout = prefs_get_inpblock();
+    gint inpblock = prefs_get_inpblock();
+    if (!prefs_get_boolean(PREF_INPBLOCK_DYNAMIC)) {
+        inp_timeout = inpblock;
         return;
     }
 
@@ -242,14 +268,14 @@ inp_nonblocking(gboolean reset)
         no_input_count = 0;
     }
 
-    if (inp_timeout < prefs_get_inpblock()) {
+    if (inp_timeout < inpblock) {
         no_input_count++;
 
         if (no_input_count % 10 == 0) {
             inp_timeout += no_input_count;
 
-            if (inp_timeout > prefs_get_inpblock()) {
-                inp_timeout = prefs_get_inpblock();
+            if (inp_timeout > inpblock) {
+                inp_timeout = inpblock;
             }
         }
     }
@@ -259,7 +285,10 @@ void
 inp_close(void)
 {
     rl_callback_handler_remove();
+    delwin(inp_win);
+    inp_win = NULL;
     fclose(discard);
+    discard = NULL;
 }
 
 char*
@@ -269,7 +298,7 @@ inp_get_line(void)
     wmove(inp_win, 0, 0);
     _inp_win_update_virtual();
     doupdate();
-    char *line = NULL;
+    char* line = NULL;
     while (!line) {
         line = inp_readline();
         ui_update();
@@ -285,7 +314,7 @@ inp_get_password(void)
     wmove(inp_win, 0, 0);
     _inp_win_update_virtual();
     doupdate();
-    char *password = NULL;
+    char* password = NULL;
     get_password = TRUE;
     while (!password) {
         password = inp_readline();
@@ -307,15 +336,47 @@ _inp_win_update_virtual(void)
 {
     int wcols = getmaxx(stdscr);
     int row = screen_inputwin_row();
-    pnoutrefresh(inp_win, 0, pad_start, row, 0, row, wcols-2);
+    if (inp_win != NULL) {
+        pnoutrefresh(inp_win, 0, pad_start, row, 0, row, wcols - 1);
+    }
 }
 
 static void
-_inp_write(char *line, int offset)
+_inp_write(char* line, int offset)
 {
+    int x;
+    int y __attribute__((unused));
     int col = _inp_offset_to_col(line, offset);
     werase(inp_win);
-    waddstr(inp_win, line);
+
+    waddstr(inp_win, rl_display_prompt);
+    getyx(inp_win, y, x);
+    col += x;
+
+    for (size_t i = 0; line[i] != '\0'; i++) {
+        char* c = &line[i];
+        char retc[PROF_MB_CUR_MAX] = { 0 };
+
+        size_t ch_len = mbrlen(c, MB_CUR_MAX, NULL);
+        if ((ch_len == (size_t)-2) || (ch_len == (size_t)-1)) {
+            waddch(inp_win, ' ');
+            continue;
+        }
+
+        if (line[i] == '\n') {
+            c = retc;
+            ch_len = wctomb(retc, L'\u23ce'); /* return symbol */
+            if (ch_len == -1) {               /* not representable */
+                retc[0] = '\\';
+                ch_len = 1;
+            }
+        } else {
+            i += ch_len - 1;
+        }
+
+        waddnstr(inp_win, c, ch_len);
+    }
+
     wmove(inp_win, 0, col);
     _inp_win_handle_scroll();
 
@@ -346,7 +407,7 @@ _inp_edited(const wint_t ch)
     }
 
     // printable
-    char bytes[MB_CUR_MAX+1];
+    char bytes[MB_CUR_MAX + 1];
     size_t utf_len = wcrtomb(bytes, ch, &mbstate);
     if (utf_len == (size_t)-1) {
         return 0;
@@ -358,7 +419,7 @@ _inp_edited(const wint_t ch)
 }
 
 static int
-_inp_offset_to_col(char *str, int offset)
+_inp_offset_to_col(char* str, int offset)
 {
     int i = 0;
     int col = 0;
@@ -366,6 +427,10 @@ _inp_offset_to_col(char *str, int offset)
     while (i < offset && str[i] != '\0') {
         gunichar uni = g_utf8_get_char(&str[i]);
         size_t ch_len = mbrlen(&str[i], MB_CUR_MAX, NULL);
+        if ((ch_len == (size_t)-2) || (ch_len == (size_t)-1)) {
+            i++;
+            continue;
+        }
         i += ch_len;
         col++;
         if (g_unichar_iswide(uni)) {
@@ -384,7 +449,7 @@ _inp_win_handle_scroll(void)
 
     if (col == 0) {
         pad_start = 0;
-    } else if (col >= pad_start + (wcols -2)) {
+    } else if (col >= pad_start + (wcols - 1)) {
         pad_start = col - (wcols / 2);
         if (pad_start < 0) {
             pad_start = 0;
@@ -423,12 +488,19 @@ _inp_rl_addfuncs(void)
     rl_add_funmap_entry("prof_win_prev", _inp_rl_win_prev_handler);
     rl_add_funmap_entry("prof_win_next", _inp_rl_win_next_handler);
     rl_add_funmap_entry("prof_win_next_unread", _inp_rl_win_next_unread_handler);
+    rl_add_funmap_entry("prof_win_set_attention", _inp_rl_win_attention_handler);
+    rl_add_funmap_entry("prof_win_attention_next", _inp_rl_win_attention_next_handler);
     rl_add_funmap_entry("prof_win_pageup", _inp_rl_win_pageup_handler);
     rl_add_funmap_entry("prof_win_pagedown", _inp_rl_win_pagedown_handler);
     rl_add_funmap_entry("prof_subwin_pageup", _inp_rl_subwin_pageup_handler);
     rl_add_funmap_entry("prof_subwin_pagedown", _inp_rl_subwin_pagedown_handler);
+    rl_add_funmap_entry("prof_complete_next", _inp_rl_tab_handler);
+    rl_add_funmap_entry("prof_complete_prev", _inp_rl_shift_tab_handler);
     rl_add_funmap_entry("prof_win_clear", _inp_rl_win_clear_handler);
     rl_add_funmap_entry("prof_win_close", _inp_rl_win_close_handler);
+    rl_add_funmap_entry("prof_send_to_editor", _inp_rl_send_to_editor);
+    rl_add_funmap_entry("prof_cut_to_history", _inp_rl_down_arrow_handler);
+    rl_add_funmap_entry("prof_print_newline_symbol", _inp_rl_print_newline_symbol);
 }
 
 // Readline callbacks
@@ -471,12 +543,17 @@ _inp_rl_startup_hook(void)
     rl_bind_keyseq("\\e[1;9D", _inp_rl_win_prev_handler);
     rl_bind_keyseq("\\e[1;3D", _inp_rl_win_prev_handler);
     rl_bind_keyseq("\\e\\e[D", _inp_rl_win_prev_handler);
+    rl_bind_keyseq("\\e\\eOD", _inp_rl_win_prev_handler);
 
     rl_bind_keyseq("\\e[1;9C", _inp_rl_win_next_handler);
     rl_bind_keyseq("\\e[1;3C", _inp_rl_win_next_handler);
     rl_bind_keyseq("\\e\\e[C", _inp_rl_win_next_handler);
+    rl_bind_keyseq("\\e\\eOC", _inp_rl_win_next_handler);
 
     rl_bind_keyseq("\\ea", _inp_rl_win_next_unread_handler);
+    rl_bind_keyseq("\\ev", _inp_rl_win_attention_handler);
+    rl_bind_keyseq("\\em", _inp_rl_win_attention_next_handler);
+    rl_bind_keyseq("\\ec", _inp_rl_send_to_editor);
 
     rl_bind_keyseq("\\e\\e[5~", _inp_rl_subwin_pageup_handler);
     rl_bind_keyseq("\\e[5;3~", _inp_rl_subwin_pageup_handler);
@@ -494,7 +571,12 @@ _inp_rl_startup_hook(void)
     rl_bind_key('\t', _inp_rl_tab_handler);
     rl_bind_keyseq("\\e[Z", _inp_rl_shift_tab_handler);
 
+    rl_bind_keyseq("\\e[1;3A", _inp_rl_scroll_handler);     // alt + scroll/arrow up
+    rl_bind_keyseq("\\e[1;3B", _inp_rl_scroll_handler);     // alt + scroll/arrow down
     rl_bind_keyseq("\\e[1;5B", _inp_rl_down_arrow_handler); // ctrl+arrow down
+    rl_bind_keyseq("\\eOb", _inp_rl_down_arrow_handler);
+
+    rl_bind_keyseq("\\e\\C-\r", _inp_rl_print_newline_symbol); // alt+enter
 
     // unbind unwanted mappings
     rl_bind_keyseq("\\e=", NULL);
@@ -503,30 +585,33 @@ _inp_rl_startup_hook(void)
     rl_variable_bind("disable-completion", "on");
 
     // check for and load ~/.config/profanity/inputrc
-    gchar *inputrc = files_get_inputrc_file();
+    auto_gchar gchar* inputrc = files_get_inputrc_file();
     if (inputrc) {
         rl_read_init_file(inputrc);
-        g_free(inputrc);
     }
 
     return 0;
 }
 
 static void
-_inp_rl_linehandler(char *line)
+_inp_rl_linehandler(char* line)
 {
-    if (line && *line) {
-        if (!get_password) {
-            add_history(line);
-        }
-    }
     inp_line = line;
+    if (!line || !*line || get_password) {
+        return;
+    }
+    HISTORY_STATE* history = history_get_history_state();
+    HIST_ENTRY* last = history->length > 0 ? history->entries[history->length - 1] : NULL;
+    if (last == NULL || strcmp(last->line, line) != 0) {
+        add_history(line);
+    }
+    free(history);
 }
 
 static gboolean shift_tab = FALSE;
 
 static int
-_inp_rl_getc(FILE *stream)
+_inp_rl_getc(FILE* stream)
 {
     int ch = rl_getc(stream);
 
@@ -545,16 +630,28 @@ _inp_rl_getc(FILE *stream)
     shift_tab = FALSE;
 
     if (_inp_edited(ch)) {
-        ProfWin *window = wins_get_current();
+        ProfWin* window = wins_get_current();
         cmd_ac_reset(window);
+
+        if ((window->type == WIN_CHAT || window->type == WIN_MUC || window->type == WIN_PRIVATE) && window->quotes_ac != NULL) {
+            autocomplete_reset(window->quotes_ac);
+        }
     }
     return ch;
 }
 
+static void
+_inp_redisplay(void)
+{
+    if (!get_password) {
+        _inp_write(rl_line_buffer, rl_point);
+    }
+}
+
 static int
 _inp_rl_win_clear_handler(int count, int key)
 {
-    ProfWin *win = wins_get_current();
+    ProfWin* win = wins_get_current();
     win_clear(win);
     return 0;
 }
@@ -562,72 +659,67 @@ _inp_rl_win_clear_handler(int count, int key)
 static int
 _inp_rl_win_close_handler(int count, int key)
 {
-    ProfWin *win = wins_get_current();
+    ProfWin* win = wins_get_current();
     gchar* args = 0;
     cmd_close(win, 0, &args);
     return 0;
 }
 
 static int
-_inp_rl_tab_handler(int count, int key)
+_inp_rl_tab_com_handler(int count, int key, gboolean previous)
 {
     if (rl_point != rl_end || !rl_line_buffer) {
         return 0;
     }
 
-    ProfWin *current = wins_get_current();
-    if ((strncmp(rl_line_buffer, "/", 1) != 0) && (current->type == WIN_MUC)) {
-        char *result = muc_autocomplete(current, rl_line_buffer, FALSE);
+    if (strncmp(rl_line_buffer, "/", 1) == 0) {
+        ProfWin* window = wins_get_current();
+        auto_char char* result = cmd_ac_complete(window, rl_line_buffer, previous);
         if (result) {
             rl_replace_line(result, 1);
             rl_point = rl_end;
-            free(result);
+            return 0;
         }
-    } else if (strncmp(rl_line_buffer, "/", 1) == 0) {
-        ProfWin *window = wins_get_current();
-        char *result = cmd_ac_complete(window, rl_line_buffer, FALSE);
+    }
+
+    if (strncmp(rl_line_buffer, ">", 1) == 0) {
+        ProfWin* window = wins_get_current();
+        auto_char char* result = win_quote_autocomplete(window, rl_line_buffer, previous);
+        if (result) {
+            rl_replace_line(result, 1);
+            rl_point = rl_end;
+            return 0;
+        }
+    }
+
+    ProfWin* current = wins_get_current();
+    if (current->type == WIN_MUC) {
+        auto_char char* result = muc_autocomplete(current, rl_line_buffer, previous);
         if (result) {
             rl_replace_line(result, 1);
             rl_point = rl_end;
-            free(result);
         }
     }
 
     return 0;
 }
 
+static int
+_inp_rl_tab_handler(int count, int key)
+{
+    return _inp_rl_tab_com_handler(count, key, FALSE);
+}
+
 static int
 _inp_rl_shift_tab_handler(int count, int key)
 {
-    if (rl_point != rl_end || !rl_line_buffer) {
-        return 0;
-    }
-
-    ProfWin *current = wins_get_current();
-    if ((strncmp(rl_line_buffer, "/", 1) != 0) && (current->type == WIN_MUC)) {
-        char *result = muc_autocomplete(current, rl_line_buffer, TRUE);
-        if (result) {
-            rl_replace_line(result, 1);
-            rl_point = rl_end;
-            free(result);
-        }
-    } else if (strncmp(rl_line_buffer, "/", 1) == 0) {
-        ProfWin *window = wins_get_current();
-        char *result = cmd_ac_complete(window, rl_line_buffer, TRUE);
-        if (result) {
-            rl_replace_line(result, 1);
-            rl_point = rl_end;
-            free(result);
-        }
-    }
-
-    return 0;
+    return _inp_rl_tab_com_handler(count, key, TRUE);
 }
 
 static void
 _go_to_win(int i)
 {
-    ProfWin *window = wins_get_by_num(i);
+    ProfWin* window = wins_get_by_num(i);
     if (window) {
         ui_focus_win(window);
     }
@@ -776,7 +868,7 @@ _inp_rl_win_20_handler(int count, int key)
 static int
 _inp_rl_win_prev_handler(int count, int key)
 {
-    ProfWin *window = wins_get_previous();
+    ProfWin* window = wins_get_previous();
     if (window) {
         ui_focus_win(window);
     }
@@ -786,7 +878,7 @@ _inp_rl_win_prev_handler(int count, int key)
 static int
 _inp_rl_win_next_handler(int count, int key)
 {
-    ProfWin *window = wins_get_next();
+    ProfWin* window = wins_get_next();
     if (window) {
         ui_focus_win(window);
     }
@@ -796,7 +888,33 @@ _inp_rl_win_next_handler(int count, int key)
 static int
 _inp_rl_win_next_unread_handler(int count, int key)
 {
-    ProfWin *window = wins_get_next_unread();
+    ProfWin* window = wins_get_next_unread();
+    if (window) {
+        ui_focus_win(window);
+    }
+    return 0;
+}
+
+static int
+_inp_rl_win_attention_handler(int count, int key)
+{
+    ProfWin* current = wins_get_current();
+    if (current) {
+        gboolean attention = win_toggle_attention(current);
+        if (attention) {
+            win_println(current, THEME_DEFAULT, "!", "Attention flag has been activated");
+        } else {
+            win_println(current, THEME_DEFAULT, "!", "Attention flag has been deactivated");
+        }
+        win_redraw(current);
+    }
+    return 0;
+}
+
+static int
+_inp_rl_win_attention_next_handler(int count, int key)
+{
+    ProfWin* window = wins_get_next_attention();
     if (window) {
         ui_focus_win(window);
     }
@@ -806,23 +924,23 @@ _inp_rl_win_next_unread_handler(int count, int key)
 static int
 _inp_rl_win_pageup_handler(int count, int key)
 {
-    ProfWin *current = wins_get_current();
-    win_page_up(current);
+    ProfWin* current = wins_get_current();
+    win_page_up(current, 0);
     return 0;
 }
 
 static int
 _inp_rl_win_pagedown_handler(int count, int key)
 {
-    ProfWin *current = wins_get_current();
-    win_page_down(current);
+    ProfWin* current = wins_get_current();
+    win_page_down(current, 0);
     return 0;
 }
 
 static int
 _inp_rl_subwin_pageup_handler(int count, int key)
 {
-    ProfWin *current = wins_get_current();
+    ProfWin* current = wins_get_current();
     win_sub_page_up(current);
     return 0;
 }
@@ -830,11 +948,26 @@ _inp_rl_subwin_pageup_handler(int count, int key)
 static int
 _inp_rl_subwin_pagedown_handler(int count, int key)
 {
-    ProfWin *current = wins_get_current();
+    ProfWin* current = wins_get_current();
     win_sub_page_down(current);
     return 0;
 }
 
+static int
+_inp_rl_scroll_handler(int count, int key)
+{
+    ProfWin* window = wins_get_current();
+
+    if (key == 'B') {
+        // mouse wheel down
+        win_page_down(window, 4);
+    } else if (key == 'A') {
+        // mouse wheel up
+        win_page_up(window, 4);
+    }
+    return 0;
+}
+
 static int
 _inp_rl_down_arrow_handler(int count, int key)
 {
@@ -844,3 +977,31 @@ _inp_rl_down_arrow_handler(int count, int key)
     rl_redisplay();
     return 0;
 }
+
+static int
+_inp_rl_send_to_editor(int count, int key)
+{
+    if (!rl_line_buffer) {
+        return 0;
+    }
+
+    auto_gchar gchar* message = NULL;
+
+    if (get_message_from_editor(rl_line_buffer, &message)) {
+        return 0;
+    }
+
+    rl_replace_line(message, 0);
+    ui_resize();
+    rl_point = rl_end;
+    rl_forced_update_display();
+
+    return 0;
+}
+
+static int
+_inp_rl_print_newline_symbol(int count, int key)
+{
+    rl_insert_text("\n");
+    return 0;
+}
