@@ -2,11 +2,8 @@
 #include <sys/wait.h>
 #include <glib.h>
 
-#include <setjmp.h>
-#include <stdarg.h>
-#include <stddef.h>
 #include <stdlib.h>
-#include <cmocka.h>
+#include "prof_cmocka.h"
 #include <stdio.h>
 #include <unistd.h>
 #include <errno.h>
@@ -23,7 +20,7 @@ char *data_orig;
 int fd = 0;
 
 gboolean
-_create_dir(char *name)
+_create_dir(const char *name)
 {
     struct stat sb;
 
@@ -138,12 +135,12 @@ prof_start(void)
     setbuf(fp, (char *)0);
 }
 
-void
+int
 init_prof_test(void **state)
 {
     if (stbbr_start(STBBR_LOGDEBUG ,5230, 0) != 0) {
         assert_true(FALSE);
-        return;
+        return -1;
     }
 
     config_orig = getenv("XDG_CONFIG_HOME");
@@ -190,9 +187,10 @@ init_prof_test(void **state)
     assert_true(prof_output_exact("Private chat time display disabled."));
     prof_input("/time xml off");
     assert_true(prof_output_exact("XML Console time display disabled."));
+    return 0;
 }
 
-void
+int
 close_prof_test(void **state)
 {
     prof_input("/quit");
@@ -203,10 +201,11 @@ close_prof_test(void **state)
     setenv("XDG_DATA_HOME", data_orig, 1);
 
     stbbr_stop();
+    return 0;
 }
 
 void
-prof_input(char *input)
+prof_input(const char *input)
 {
     GString *inp_str = g_string_new(input);
     g_string_append(inp_str, "\r");
@@ -215,19 +214,19 @@ prof_input(char *input)
 }
 
 int
-prof_output_exact(char *text)
+prof_output_exact(const char *text)
 {
     return (1 == exp_expectl(fd, exp_exact, text, 1, exp_end));
 }
 
 int
-prof_output_regex(char *text)
+prof_output_regex(const char *text)
 {
     return (1 == exp_expectl(fd, exp_regexp, text, 1, exp_end));
 }
 
 void
-prof_connect_with_roster(char *roster)
+prof_connect_with_roster(const char *roster)
 {
     GString *roster_str = g_string_new(
         "<iq type='result' to='stabber@localhost/profanity'>"
