@@ -1,7 +1,7 @@
 /*
  * stub_database.c
  *
- * Copyright (C) 2020 Michael Vetter <jubalh@iodoru.org>
+ * Copyright (C) 2020 - 2025 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
@@ -21,14 +21,32 @@
  */
 
 #include <glib.h>
-#include <setjmp.h>
-#include <cmocka.h>
+#include "prof_cmocka.h"
 
 #include "database.h"
 
-gboolean log_database_init(ProfAccount *account) { return TRUE; }
-void log_database_add_incoming(ProfMessage *message) {}
-void log_database_add_outgoing_chat(const char * const id, const char * const barejid, const char * const message, const char *const replace_id, prof_enc_t enc) {}
-void log_database_add_outgoing_muc(const char * const id, const char * const barejid, const char * const message, const char *const replace_id, prof_enc_t enc) {}
-void log_database_add_outgoing_muc_pm(const char * const id, const char * const barejid, const char * const message, const char *const replace_id, prof_enc_t enc) {}
-void log_database_close(void) {}
+gboolean
+log_database_init(ProfAccount* account)
+{
+    return TRUE;
+}
+void
+log_database_add_incoming(ProfMessage* message)
+{
+}
+void
+log_database_add_outgoing_chat(const char* const id, const char* const barejid, const char* const message, const char* const replace_id, prof_enc_t enc)
+{
+}
+void
+log_database_add_outgoing_muc(const char* const id, const char* const barejid, const char* const message, const char* const replace_id, prof_enc_t enc)
+{
+}
+void
+log_database_add_outgoing_muc_pm(const char* const id, const char* const barejid, const char* const message, const char* const replace_id, prof_enc_t enc)
+{
+}
+void
+log_database_close(void)
+{
+}
