@@ -1,8 +1,5 @@
-#include <setjmp.h>
-#include <stdarg.h>
-#include <stddef.h>
 #include <stdlib.h>
-#include <cmocka.h>
+#include "prof_cmocka.h"
 #include <glib.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -11,6 +8,9 @@
 #include "helpers.h"
 #include "config/preferences.h"
 #include "xmpp/chat_session.h"
+#include "command/cmd_defs.h"
+
+void prof_shutdown(void);
 
 void
 create_config_dir(void** state)
@@ -44,38 +44,49 @@ remove_data_dir(void** state)
     rmdir("./tests/files/xdg_data_home");
 }
 
-void
+int
 load_preferences(void** state)
 {
     create_config_dir(state);
     FILE* f = fopen("./tests/files/xdg_config_home/profanity/profrc", "ab+");
     if (f) {
         prefs_load(NULL);
+    } else {
+        return 1;
     }
     fclose(f);
+    cmd_init();
+    chat_sessions_init();
+    return 0;
 }
 
-void
+int
 close_preferences(void** state)
 {
+    chat_sessions_clear();
     prefs_close();
     remove("./tests/files/xdg_config_home/profanity/profrc");
     remove_config_dir(state);
     rmdir("./tests/files");
+    prof_shutdown();
+    return 0;
 }
 
-void
+int
 init_chat_sessions(void** state)
 {
     load_preferences(NULL);
     chat_sessions_init();
+    return 0;
 }
 
-void
+int
 close_chat_sessions(void** state)
 {
     chat_sessions_clear();
     close_preferences(NULL);
+    prof_shutdown();
+    return 0;
 }
 
 int
