@@ -1,7 +1,4 @@
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
+#include "prof_cmocka.h"
 #include <stdlib.h>
 #include <string.h>
 #include <glib.h>
@@ -22,7 +19,8 @@
 
 #define CMD_BOOKMARK "/bookmark"
 
-static void test_with_connection_status(jabber_conn_status_t status)
+static void
+test_with_connection_status(jabber_conn_status_t status)
 {
     ProfWin window;
     window.type = WIN_CONSOLE;
@@ -33,24 +31,28 @@ static void test_with_connection_status(jabber_conn_status_t status)
     assert_true(result);
 }
 
-void cmd_bookmark_shows_message_when_disconnected(void **state)
+void
+cmd_bookmark_shows_message_when_disconnected(void** state)
 {
     test_with_connection_status(JABBER_DISCONNECTED);
 }
 
-void cmd_bookmark_shows_message_when_disconnecting(void **state)
+void
+cmd_bookmark_shows_message_when_disconnecting(void** state)
 {
     test_with_connection_status(JABBER_DISCONNECTING);
 }
 
-void cmd_bookmark_shows_message_when_connecting(void **state)
+void
+cmd_bookmark_shows_message_when_connecting(void** state)
 {
     test_with_connection_status(JABBER_CONNECTING);
 }
 
-void cmd_bookmark_shows_usage_when_no_args(void **state)
+void
+cmd_bookmark_shows_usage_when_no_args(void** state)
 {
-    gchar *args[] = { NULL };
+    gchar* args[] = { NULL };
     ProfWin window;
     window.type = WIN_CONSOLE;
 
@@ -72,7 +74,7 @@ static void _free_bookmark(Bookmark *bookmark)
 */
 
 static gboolean
-_cmp_bookmark(Bookmark *bm1, Bookmark *bm2)
+_cmp_bookmark(Bookmark* bm1, Bookmark* bm2)
 {
     if (strcmp(bm1->barejid, bm2->barejid) != 0) {
         return FALSE;
@@ -87,30 +89,31 @@ _cmp_bookmark(Bookmark *bm1, Bookmark *bm2)
     return TRUE;
 }
 
-void cmd_bookmark_list_shows_bookmarks(void **state)
+void
+cmd_bookmark_list_shows_bookmarks(void** state)
 {
-    gchar *args[] = { "list", NULL };
-    GList *bookmarks = NULL;
+    gchar* args[] = { "list", NULL };
+    GList* bookmarks = NULL;
     ProfWin window;
     window.type = WIN_CONSOLE;
 
-    Bookmark *bm1 = malloc(sizeof(Bookmark));
+    Bookmark* bm1 = malloc(sizeof(Bookmark));
     bm1->barejid = strdup("room1@conf.org");
     bm1->nick = strdup("bob");
     bm1->autojoin = FALSE;
-    Bookmark *bm2 = malloc(sizeof(Bookmark));
+    Bookmark* bm2 = malloc(sizeof(Bookmark));
     bm2->barejid = strdup("room2@conf.org");
     bm2->nick = strdup("steve");
     bm2->autojoin = TRUE;
-    Bookmark *bm3 = malloc(sizeof(Bookmark));
+    Bookmark* bm3 = malloc(sizeof(Bookmark));
     bm3->barejid = strdup("room3@conf.org");
     bm3->nick = strdup("dave");
     bm3->autojoin = TRUE;
-    Bookmark *bm4 = malloc(sizeof(Bookmark));
+    Bookmark* bm4 = malloc(sizeof(Bookmark));
     bm4->barejid = strdup("room4@conf.org");
     bm4->nick = strdup("james");
     bm4->autojoin = FALSE;
-    Bookmark *bm5 = malloc(sizeof(Bookmark));
+    Bookmark* bm5 = malloc(sizeof(Bookmark));
     bm5->barejid = strdup("room5@conf.org");
     bm5->nick = strdup("mike");
     bm5->autojoin = FALSE;
@@ -148,10 +151,11 @@ void cmd_bookmark_list_shows_bookmarks(void **state)
     free(bm5);
 }
 
-void cmd_bookmark_add_shows_message_when_invalid_jid(void **state)
+void
+cmd_bookmark_add_shows_message_when_invalid_jid(void** state)
 {
-    char *jid = "room";
-    gchar *args[] = { "add", jid, NULL };
+    char* jid = "room";
+    gchar* args[] = { "add", jid, NULL };
     ProfWin window;
     window.type = WIN_CONSOLE;
 
@@ -164,10 +168,11 @@ void cmd_bookmark_add_shows_message_when_invalid_jid(void **state)
     assert_true(result);
 }
 
-void cmd_bookmark_add_adds_bookmark_with_jid(void **state)
+void
+cmd_bookmark_add_adds_bookmark_with_jid(void** state)
 {
-    char *jid = "room@conf.server";
-    gchar *args[] = { "add", jid, NULL };
+    char* jid = "room@conf.server";
+    gchar* args[] = { "add", jid, NULL };
     ProfWin window;
     window.type = WIN_CONSOLE;
 
@@ -185,11 +190,10 @@ void cmd_bookmark_add_adds_bookmark_with_jid(void **state)
     assert_true(result);
 }
 
-void cmd_bookmark_uses_roomjid_in_room(void **state)
+void
+cmd_bookmark_uses_roomjid_in_room(void** state)
 {
-    muc_init();
-
-    gchar *args[] = { NULL };
+    gchar* args[] = { NULL };
     ProfMucWin muc_win;
     muc_win.window.type = WIN_MUC;
     muc_win.memcheck = PROFMUCWIN_MEMCHECK;
@@ -207,15 +211,12 @@ void cmd_bookmark_uses_roomjid_in_room(void **state)
 
     gboolean result = cmd_bookmark(&muc_win.window, CMD_BOOKMARK, args);
     assert_true(result);
-
-    muc_close();
 }
 
-void cmd_bookmark_add_uses_roomjid_in_room(void **state)
+void
+cmd_bookmark_add_uses_roomjid_in_room(void** state)
 {
-    muc_init();
-
-    gchar *args[] = { "add", NULL };
+    gchar* args[] = { "add", NULL };
     ProfMucWin muc_win;
     muc_win.window.type = WIN_MUC;
     muc_win.memcheck = PROFMUCWIN_MEMCHECK;
@@ -233,16 +234,13 @@ void cmd_bookmark_add_uses_roomjid_in_room(void **state)
 
     gboolean result = cmd_bookmark(&muc_win.window, CMD_BOOKMARK, args);
     assert_true(result);
-
-    muc_close();
 }
 
-void cmd_bookmark_add_uses_supplied_jid_in_room(void **state)
+void
+cmd_bookmark_add_uses_supplied_jid_in_room(void** state)
 {
-    muc_init();
-
-    char *jid = "room1@conf.server";
-    gchar *args[] = { "add", jid, NULL };
+    char* jid = "room1@conf.server";
+    gchar* args[] = { "add", jid, NULL };
     ProfMucWin muc_win;
     muc_win.window.type = WIN_MUC;
     muc_win.memcheck = PROFMUCWIN_MEMCHECK;
@@ -260,15 +258,14 @@ void cmd_bookmark_add_uses_supplied_jid_in_room(void **state)
 
     gboolean result = cmd_bookmark(&muc_win.window, CMD_BOOKMARK, args);
     assert_true(result);
-
-    muc_close();
 }
 
-void cmd_bookmark_add_adds_bookmark_with_jid_nick(void **state)
+void
+cmd_bookmark_add_adds_bookmark_with_jid_nick(void** state)
 {
-    char *jid = "room@conf.server";
-    char *nick = "bob";
-    gchar *args[] = { "add", jid, "nick", nick, NULL };
+    char* jid = "room@conf.server";
+    char* nick = "bob";
+    gchar* args[] = { "add", jid, "nick", nick, NULL };
     ProfWin window;
     window.type = WIN_CONSOLE;
 
@@ -286,10 +283,11 @@ void cmd_bookmark_add_adds_bookmark_with_jid_nick(void **state)
     assert_true(result);
 }
 
-void cmd_bookmark_add_adds_bookmark_with_jid_autojoin(void **state)
+void
+cmd_bookmark_add_adds_bookmark_with_jid_autojoin(void** state)
 {
-    char *jid = "room@conf.server";
-    gchar *args[] = { "add", jid, "autojoin", "on", NULL };
+    char* jid = "room@conf.server";
+    gchar* args[] = { "add", jid, "autojoin", "on", NULL };
     ProfWin window;
     window.type = WIN_CONSOLE;
 
@@ -307,11 +305,12 @@ void cmd_bookmark_add_adds_bookmark_with_jid_autojoin(void **state)
     assert_true(result);
 }
 
-void cmd_bookmark_add_adds_bookmark_with_jid_nick_autojoin(void **state)
+void
+cmd_bookmark_add_adds_bookmark_with_jid_nick_autojoin(void** state)
 {
-    char *jid = "room@conf.server";
-    char *nick = "bob";
-    gchar *args[] = { "add", jid, "nick", nick, "autojoin", "on", NULL };
+    char* jid = "room@conf.server";
+    char* nick = "bob";
+    gchar* args[] = { "add", jid, "nick", nick, "autojoin", "on", NULL };
     ProfWin window;
     window.type = WIN_CONSOLE;
 
@@ -329,10 +328,11 @@ void cmd_bookmark_add_adds_bookmark_with_jid_nick_autojoin(void **state)
     assert_true(result);
 }
 
-void cmd_bookmark_remove_removes_bookmark(void **state)
+void
+cmd_bookmark_remove_removes_bookmark(void** state)
 {
-    char *jid = "room@conf.server";
-    gchar *args[] = { "remove", jid, NULL };
+    char* jid = "room@conf.server";
+    gchar* args[] = { "remove", jid, NULL };
     ProfWin window;
     window.type = WIN_CONSOLE;
 
@@ -347,10 +347,11 @@ void cmd_bookmark_remove_removes_bookmark(void **state)
     assert_true(result);
 }
 
-void cmd_bookmark_remove_shows_message_when_no_bookmark(void **state)
+void
+cmd_bookmark_remove_shows_message_when_no_bookmark(void** state)
 {
-    char *jid = "room@conf.server";
-    gchar *args[] = { "remove", jid, NULL };
+    char* jid = "room@conf.server";
+    gchar* args[] = { "remove", jid, NULL };
     ProfWin window;
     window.type = WIN_CONSOLE;
 
@@ -365,11 +366,10 @@ void cmd_bookmark_remove_shows_message_when_no_bookmark(void **state)
     assert_true(result);
 }
 
-void cmd_bookmark_remove_uses_roomjid_in_room(void **state)
+void
+cmd_bookmark_remove_uses_roomjid_in_room(void** state)
 {
-    muc_init();
-
-    gchar *args[] = { "remove", NULL };
+    gchar* args[] = { "remove", NULL };
     ProfMucWin muc_win;
     muc_win.window.type = WIN_MUC;
     muc_win.memcheck = PROFMUCWIN_MEMCHECK;
@@ -384,16 +384,13 @@ void cmd_bookmark_remove_uses_roomjid_in_room(void **state)
 
     gboolean result = cmd_bookmark(&muc_win.window, CMD_BOOKMARK, args);
     assert_true(result);
-
-    muc_close();
 }
 
-void cmd_bookmark_remove_uses_supplied_jid_in_room(void **state)
+void
+cmd_bookmark_remove_uses_supplied_jid_in_room(void** state)
 {
-    muc_init();
-
-    char *jid = "room1@conf.server";
-    gchar *args[] = { "remove", jid, NULL };
+    char* jid = "room1@conf.server";
+    gchar* args[] = { "remove", jid, NULL };
     ProfMucWin muc_win;
     muc_win.window.type = WIN_MUC;
     muc_win.memcheck = PROFMUCWIN_MEMCHECK;
@@ -408,6 +405,4 @@ void cmd_bookmark_remove_uses_supplied_jid_in_room(void **state)
 
     gboolean result = cmd_bookmark(&muc_win.window, CMD_BOOKMARK, args);
     assert_true(result);
-
-    muc_close();
 }
